@@ -229,21 +229,8 @@ class Framer(tasking.Tasker):
             clone = original.clone(name=clone, schedule=schedule)
 
             # inode is new (aux verb clone via)  clone.inode is old (framer moot via)
-            if inode == "mine":  # new == "mine" so use old to determine
-                if clone.inode == "mine":  # effective "mine"
-                    clone.inode = ""  # so make empty
-                elif (clone.inode != "main" and
-                        not clone.inode.startswith('.')):  # relative and not "main"
-                    clone.inode = ".{0}".format(clone.inode)  # so make absolute
-                    # otherwise old == "main" or absolute
-                    # leave old as is which may be "main"
-                    # when "main" will get substitued later for main framer inode
-            elif inode == "":  # empty so use old to determine
-                if clone.inode == "mine":  # effective "mine"
-                    clone.inode = ""  # so make empty
-                # otherwise leave old as is
-            else:  # replace old with new
-                clone.inode = inode
+            if inode:  # new != "" so resultant is new
+                clone.inode = inode  # replace old with new
 
             clone.original = False  # main frame will be fixed
             self.store.house.resolvables.append(clone)
@@ -762,6 +749,7 @@ class Frame(registering.StoriedRegistrar):
 
         instance attributes
             .framer = link to framer that executes this frame
+            .inode = inode path to prepend to data store path refs
             .over = link to frame immediately above this one in hierarchy
             .under = property link to primary frame immediately below this one in hierarchy
             .unders = list of all frames immediately below this one
@@ -785,7 +773,7 @@ class Frame(registering.StoriedRegistrar):
     Counter = 0
     Names = odict()
 
-    def __init__(self, framer = None, **kw):
+    def __init__(self, framer=None, inode='', **kw):
         """Initialize instance.
 
         """
@@ -794,14 +782,15 @@ class Frame(registering.StoriedRegistrar):
 
         super(Frame,self).__init__(**kw)
 
-        self.framer = framer #link to framer that executes this frame
-        self.over = None # link to frame above this one, None if no frame above
-        self.unders = [] #list of frames below this one, first one is primary under
-        self.outline = [] #list of frames in outline top down order.
-        self.head = [] #list of frames from top down to self
-        self.human = '' #string of names of frames in outline '>' separated
-        self.headHuman = '' #string of names of frames in head '>' separated
-        self.next_ = None #next frame used by builder for transitions to next
+        self.framer = framer  # link to framer that executes this frame
+        self.inode = inode  # path fragment to prepend to act store path refs
+        self.over = None  # link to frame above this one, None if no frame above
+        self.unders = []  # list of frames below this one, first one is primary under
+        self.outline = []  # list of frames in outline top down order.
+        self.head = []  # list of frames from top down to self
+        self.human = ''  # string of names of frames in outline '>' separated
+        self.headHuman = ''  # string of names of frames in head '>' separated
+        self.next_ = None   #next frame used by builder for transitions to next
 
         self.beacts = [] #list of enter need acts callables that return True or False
         self.preacts = [] #list of pre-recurring acts  callables upon pre recurrence
@@ -824,7 +813,8 @@ class Frame(registering.StoriedRegistrar):
         """
         clone = Frame(name=self.name,
                       store=self.store,
-                      framer=framer.name) # only name so resolve framer later
+                      framer=framer.name,  # only name so resolve framer later
+                      inode=self.inode)
         console.terse("           Cloning Frame '{0}' into Framer '{1}'\n".format(
                                clone.name, framer.name))
 
@@ -1014,21 +1004,8 @@ class Frame(registering.StoriedRegistrar):
                 clone.insular =  True #  local to this framer
 
                 # inode is new (aux verb clone via)  clone.inode is old (framer moot via)
-                if inode == "mine":  # new == "mine" so use old to determine
-                    if clone.inode == "mine":  # effective "mine"
-                        clone.inode = ""  # so make empty
-                    elif (clone.inode != "main" and
-                            not clone.inode.startswith('.')):  # relative and not "main"
-                        clone.inode = ".{0}".format(clone.inode)  # so make absolute
-                        # otherwise old == "main" or absolute
-                        # leave old as is which may be "main"
-                        # when "main" will get substitued later for main framer inode
-                elif inode == "":  # empty so use old to determine
-                    if clone.inode == "mine":  # effective "mine"
-                        clone.inode = ""  # so make empty
-                    # otherwise leave old as is
-                else:  # replace old with new
-                    clone.inode = inode
+                if inode:  # new != "" so resultant is new
+                    clone.inode = inode  # replace old with new
 
                 self.auxes[i] = aux = clone
                 self.store.house.resolvables.append(clone)
