@@ -11,16 +11,30 @@ from collections import deque
 import random
 
 
-
+from ....aid.sixing import *
 from ....base.globaling import *
-from ....base.odicting import odict
-from ....base import aiding
-from ....base import deeding
+from ....aid.odicting import odict
+from ....aid import aiding, navigating
+from ....aid.navigating import DEGTORAD, RADTODEG
+from ....base import doing
 
-from ....base.consoling import getConsole
+from ....aid.consoling import getConsole
 console = getConsole()
 
-class SimulatorMotionUuv(deeding.DeedLapse):
+class SimulatorBase(doing.DoerLapse):
+    """
+    Base class to provide backwards compatible ._initio interface
+    """
+    def _initio(self, ioinits):
+        """
+        Initialize Actor data store interface from ioinits odict
+        Wrapper for backwards compatibility to new ._initio signature
+        """
+        self._prepio(**ioinits)
+        return (None, odict())
+
+
+class SimulatorMotionUuv(SimulatorBase):
     """UUV motion simulator class
     """
     Ioinits=odict(
@@ -55,8 +69,7 @@ class SimulatorMotionUuv(deeding.DeedLapse):
                              depth = None, depthRate = None, altitude = None,
                              heading = None, headingRate = None)
 
-
-    def _initio(self, group, speed, speedRate, velocity,
+    def _prepio(self, group, speed, speedRate, velocity,
                  depth, depthRate, pitch, pitchRate, altitude,
                  heading, headingRate, position, location,
                  rpm, stern, rudder, current, bottom, onset, origin, parms = None, **kw):
@@ -272,7 +285,7 @@ class SimulatorMotionUuv(deeding.DeedLapse):
         #average heading over time lapse to calc position change must avg before wrap around
         headAvg = (heading + headingLast)/2.0
         #don't remember why want heading to be [0, 360] instead of [-180, 180]
-        #if the latter we could use aiding.Wrap2()
+        #if the latter we could use navigating.Wrap2()
         heading %= 360.0 #mod 360 to wrap aound
         if (heading < 0.0): #if negative make equiv positive
             heading += 360.0
@@ -300,7 +313,7 @@ class SimulatorMotionUuv(deeding.DeedLapse):
 
         self.position.update(north = north + deltaNorth, east = east + deltaEast)
 
-        lat, lon = aiding.SphereLLByDNDEToLL(self.location.data.lat,self.location.data.lon,deltaNorth,deltaEast)
+        lat, lon = navigating.SphereLLByDNDEToLL(self.location.data.lat,self.location.data.lon,deltaNorth,deltaEast)
         self.location.update(lat = lat, lon = lon)
 
     def _expose(self):
@@ -317,7 +330,7 @@ class SimulatorMotionUuv(deeding.DeedLapse):
               (self.velocity.data.north, self.velocity.data.east,
                self.position.data.north, self.position.data.east))
 
-class SimulatorMotionUsv(deeding.DeedLapse):
+class SimulatorMotionUsv(SimulatorBase):
     """USV motion simulator class
     """
     Ioinits=odict(
@@ -342,7 +355,7 @@ class SimulatorMotionUsv(deeding.DeedLapse):
         self.ionames = dict( speed = None, speedRate = None,
                              heading = None, headingRate = None)
 
-    def _initio(self, group, speed, speedRate,  velocity,
+    def _prepio(self, group, speed, speedRate,  velocity,
                  heading, headingRate, position,
                  rpm, rudder, current, onset, parms = None, **kw):
         """ Override since legacy interface
@@ -478,7 +491,7 @@ class SimulatorMotionUsv(deeding.DeedLapse):
         #average heading over time lapse to calc position change must avg before wrap around
         headAvg = (heading + headingLast)/2.0
         #don't remember why want heading to be [0, 360] instead of [-180, 180]
-        #if the latter we could use aiding.Wrap2()
+        #if the latter we could use navigating.Wrap2()
         heading %= 360.0 #mod 360 to wrap around
         if (heading < 0.0): #if negative make equiv positive
             heading += 360.0
@@ -517,7 +530,7 @@ class SimulatorMotionUsv(deeding.DeedLapse):
               (self.velocity.data.north, self.velocity.data.east,
                self.position.data.north, self.position.data.east))
 
-class SimulatorSensorGps(deeding.DeedLapse):
+class SimulatorSensorGps(SimulatorBase):
     """GPS sensor simulator class
     """
     Ioinits=odict(
@@ -536,7 +549,7 @@ class SimulatorSensorGps(deeding.DeedLapse):
         #call super class method
         super(SimulatorSensorGps,self).__init__(**kw)
 
-    def _initio(self, group, positionOut, velocityOut, error,
+    def _prepio(self, group, positionOut, velocityOut, error,
                  heading, speed,  positionIn, velocityIn,
                  scenario, parms = None, **kw):
         """ Override since legacy interface
@@ -688,7 +701,7 @@ class SimulatorSensorGps(deeding.DeedLapse):
               (self.position.data.north, self.position.data.east,
                self.velocity.data.north, self.velocity.data.east))
 
-class SimulatorSensorDvl(deeding.DeedLapse):
+class SimulatorSensorDvl(SimulatorBase):
     """DVLSensorSimulator DeedLapse Deed Class
        DVL sensor simulator class
     """
@@ -708,7 +721,7 @@ class SimulatorSensorDvl(deeding.DeedLapse):
         #call super class method
         super(SimulatorSensorDvl,self).__init__(**kw)
 
-    def _initio(self, group, velocity, currentOut, altitude,
+    def _prepio(self, group, velocity, currentOut, altitude,
                  heading, speed, currentIn, bottom,
                  scenario, parms = None, **kw):
         """ Override since legacy interface
@@ -821,7 +834,7 @@ class SimulatorSensorDvl(deeding.DeedLapse):
         asigma = self.parm.data.altSigma
 
         #transform to body forward starboard
-        cf, cs = aiding.RotateNEToFS(heading, cn, ce)
+        cf, cs = navigating.RotateNEToFS(heading, cn, ce)
         vf = speed + cf
         vs = cs
 
@@ -836,7 +849,7 @@ class SimulatorSensorDvl(deeding.DeedLapse):
         noise = min(vsigma3, max(-vsigma3, random.gauss(0.0, vsigma)))
         cf += noise
         cs += noise
-        cn, ce = aiding.RotateFSToNE(heading, cf, cs)
+        cn, ce = navigating.RotateFSToNE(heading, cf, cs)
 
         asigma3 = asigma * 3.0
         noise = min(asigma3, max(-asigma3, random.gauss(0.0, asigma)))
@@ -859,7 +872,7 @@ class SimulatorSensorDvl(deeding.DeedLapse):
                self.current.data.forward, self.current.data.starboard,
                self.altitude.value))
 
-class SimulatorSensorCompass(deeding.DeedLapse):
+class SimulatorSensorCompass(SimulatorBase):
     """compass sensor simulator class
     """
     Ioinits = odict(
@@ -875,7 +888,7 @@ class SimulatorSensorCompass(deeding.DeedLapse):
         #call super class method
         super(SimulatorSensorCompass,self).__init__(**kw)
 
-    def _initio(self, group, output,input, scenario, parms = None, **kw):
+    def _prepio(self, group, output,input, scenario, parms = None, **kw):
         """ Override since legacy interface
 
             group is path name of group in store, group has following subgroups or shares:
@@ -972,7 +985,7 @@ class SimulatorSensorCompass(deeding.DeedLapse):
               (self.output.value, self.parm.data.phase,
                self.parm.data.amp, self.parm.data.sigma))
 
-class SimulatorSalinityLinear(deeding.DeedLapse):
+class SimulatorSalinityLinear(SimulatorBase):
     """linear salinity simulator class
     """
     Ioinits = odict(
@@ -998,7 +1011,7 @@ class SimulatorSalinityLinear(deeding.DeedLapse):
         super(SimulatorSalinityLinear,self).__init__(**kw)
 
 
-    def _initio(self, group, output,input, depth, parms = None, **kw):
+    def _prepio(self, group, output,input, depth, parms = None, **kw):
         """ Override since legacy interface
 
                        group is path name of group in store, group has following subgroups or shares:
@@ -1088,7 +1101,7 @@ class SimulatorSalinityLinear(deeding.DeedLapse):
         shift = self.parm.data.shift
 
         #generate distance of vehicle from center track
-        d = aiding.DistancePointToTrack2D([east,north],track, [pe,pn])
+        d = navigating.DistancePointToTrack2D([east,north],track, [pe,pn])
         #shift center pos to right so shift d neg to left
         d -= (self.depth.value - layer) * shift
         d = max(- width/2.0, min( width/2.0, d)) #saturate
@@ -1117,7 +1130,7 @@ class SimulatorSalinityLinear(deeding.DeedLapse):
                self.parm.data.spread, self.parm.data.rising, self.parm.data.width,
                self.parm.data.layer, self.parm.data.shift))
 
-class SimulatorSalinitySinusoid(deeding.DeedLapse):
+class SimulatorSalinitySinusoid(SimulatorBase):
     """salinity sensor simulator class
     """
     Ioinits = odict(
@@ -1135,7 +1148,7 @@ class SimulatorSalinitySinusoid(deeding.DeedLapse):
         #call super class method
         super(SimulatorSalinitySinusoid,self).__init__(**kw)
 
-    def _initio(self, group, output,input, parms = None, **kw):
+    def _prepio(self, group, output,input, parms = None, **kw):
         """ Override since legacy interface
 
                        group is path name of group in store, group has following subgroups or shares:
@@ -1218,7 +1231,7 @@ class SimulatorSalinitySinusoid(deeding.DeedLapse):
         width = self.parm.data.width #spacial width of salinity front spread
 
         #generate signed distance of vehicle from center track (positive left)
-        d = aiding.DistancePointToTrack2D([east,north],track, [pe,pn])
+        d = navigating.DistancePointToTrack2D([east,north],track, [pe,pn])
 
         d = max(- width/2.0, min( width/2.0, d)) #saturate
 
@@ -1244,7 +1257,7 @@ class SimulatorSalinitySinusoid(deeding.DeedLapse):
                self.parm.data.north, self.parm.data.east, self.parm.data.middle,
                self.parm.data.spread, self.parm.data.rising, self.parm.data.width))
 
-class SimulatorGradient(deeding.DeedLapse):
+class SimulatorGradient(SimulatorBase):
     """gradient simulator class
     """
     Ioinits = odict(
@@ -1261,7 +1274,7 @@ class SimulatorGradient(deeding.DeedLapse):
         #call super class method
         super(SimulatorGradient,self).__init__(**kw)
 
-    def _initio(self, group, output, field, position, depth, parms = None, **kw):
+    def _prepio(self, group, output, field, position, depth, parms = None, **kw):
         """ Override since legacy interface
 
                        group is path name of group in store, group has following subgroups or shares:
@@ -1362,7 +1375,7 @@ class SimulatorGradient(deeding.DeedLapse):
         duct = self. parm.data.duct #Type of variation of output with depth in depth
 
         #horizontal distance of vehicle from center track
-        dh = aiding.DistancePointToTrack2D([east,north],track, [pe,pn])
+        dh = navigating.DistancePointToTrack2D([east,north],track, [pe,pn])
         #vertical distance from layer (pos below)
         dv = self.depth.value - layer
 
